@@ -101,7 +101,7 @@ def check_api():
         file_path = file_path[0]
         debug.log('glob filepath: {}'.format(file_path))
 
-        if check_too_old(file_path, MAX_FILE_AGE):
+        if check_too_old(file_path, MAX_FILE_AGE*2):
             svars['skipscript'] = True
             debug.log('file too old')
         else:
