@@ -47,12 +47,12 @@ def run_api(api_key, max_minutes, max_characters, max_items, language, tags):
     debug.log('max_file_age: {}'.format(max_file_age))
 
     if language == 'NL':
-        info.log('change language to dutch')
+        debug.log('change language to dutch')
         change_language(DUTCH_INDEX)
         datetime_format_new = '%d %B %Y'
         language_index = DUTCH_INDEX
     else:
-        info.log('change language to english')
+        debug.log('change language to english')
         change_language(ENGLISH_INDEX)
         datetime_format_new = '%B %d %Y'
         language_index = ENGLISH_INDEX
@@ -94,7 +94,7 @@ def run_api(api_key, max_minutes, max_characters, max_items, language, tags):
 def check_api(max_minutes, tag, min_items):
     svars = variables()
 
-    max_file_age = 60 * max_minutes
+    max_file_age = 60 * max_minutes + 2
 
     debug.log('max_file_age: {}'.format(max_file_age))
 
