@@ -92,7 +92,7 @@ def check_api(station):
         file_path = file_path[0]
         debug.log('glob filepath: {}'.format(file_path))
 
-        if check_too_old(file_path, MAX_FILE_AGE_DEPARTURES):
+        if check_too_old(file_path, MAX_FILE_AGE_DEPARTURES*2):
             svars['skipscript'] = True
             info.log('file too old')
         else:
