@@ -122,26 +122,36 @@ def check_api(news_categories):
 
     svars['total_categories'] = count_categories
 
-    for file in list_files_dir(LOCAL_PATH):
-        debug.log('file: {}'.format(file))
-        if 'xml' in file:
-            file_path = os.path.join(LOCAL_PATH, file)
-            debug.log('file path: {}'.format(file_path))
-            if check_too_old(file_path, MAX_FILE_AGE):
-                svars['skipscript'] = True
-                info.log('file too old')
-                break
-            else:
-                svars['skipscript'] = False
+    files = list_files_dir(LOCAL_PATH)
 
-                amount_items = len(xml_to_root(file_path))
-
-                if amount_items == 0:
+    if len(files) > 0:
+        file_found = False
+        for file in files:
+            debug.log('file: {}'.format(file))
+            if 'xml' in file:
+                file_found = True
+                file_path = os.path.join(LOCAL_PATH, file)
+                debug.log('file path: {}'.format(file_path))
+                if check_too_old(file_path, MAX_FILE_AGE):
                     svars['skipscript'] = True
-                    warn.log('file has no news items')
+                    info.log('file too old')
                     break
-                
-                svars['total_items'] = amount_items
+                else:
+                    svars['skipscript'] = False
+
+                    amount_items = len(xml_to_root(file_path))
+
+                    if amount_items == 0:
+                        svars['skipscript'] = True
+                        warn.log('file has no news items')
+                        break
+                    
+                    svars['total_items'] = amount_items
+        
+        if not file_found:
+            svars['skipscript'] = True
+    else:
+        svars['skipscript'] = True
 
 
 ##################################################################################################
