@@ -1,3 +1,11 @@
+from firstimpression.api.request import request
+import xml.etree.ElementTree as ET
+
+
+def get_xml(url):
+    response = request(url)
+    return ET.fromstring(response.content)
+
 
 def get_text_from_element(element, tag_name):
     return element.find(tag_name).text
